@@ -2,7 +2,7 @@
 /*****************************************************************************
  * KWATCH --- KDE Log File Viewer
  *
- * $Id: klogwidget.cpp,v 0.11 2000/12/14 20:37:23 mj Exp $
+ * $Id: klogwidget.cpp,v 0.14 2001/01/30 11:40:55 mj Exp $
  *
  * QMultiLineEdit based widget for viewing log files
  *
@@ -52,7 +52,6 @@
 /*
  * KLogFile
  */
-
 KLogFile::KLogFile(const QString &name, QObject *parent, kwatchConf &cf)
     : QObject(parent), m_cf(cf)
 {
@@ -120,9 +119,8 @@ bool KLogFile::readMore()
 /*
  * KLogWidget
  */
-
 KLogWidget::KLogWidget(QWidget *parent, kwatchConf &cf)
-    : QMultiLineEdit(parent), m_cf(cf),
+    : QMultiLineEdit(parent), m_cf(cf), m_popup(0),
       m_timer(0), m_files(0), m_current(0),
       m_r(0), m_c(0)
 {
@@ -154,9 +152,30 @@ KLogWidget::~KLogWidget()
 
 
 
+void KLogWidget::setPopupMenu(QPopupMenu *popup)
+{
+    m_popup = popup;
+}
+
+
+
+void KLogWidget::mousePressEvent(QMouseEvent *e)
+{
+    if(m_popup && e->button() == RightButton)
+    {
+	m_popup->popup(QCursor::pos());
+    }
+    else 
+    {
+	QMultiLineEdit::mousePressEvent(e);
+    }
+}
+
+
+
 void KLogWidget::dropEvent(QDropEvent *ev)
 {
-    fprintf(stderr, "KLogWidget::dropEvent()\n");
+//    fprintf(stderr, "KLogWidget::dropEvent()\n");
 
     if(QUriDrag::canDecode(ev))
     {
@@ -168,8 +187,8 @@ void KLogWidget::dropEvent(QDropEvent *ev)
 	    for (it=files.begin(); it!=files.end(); it++)
 	    {
 		QString f = (*it);
-		fprintf(stderr, "KLogWidget::dropEvent() - file = %s\n",
-			(const char *)f);
+//		fprintf(stderr, "KLogWidget::dropEvent() - file = %s\n",
+//			(const char *)f);
 
 		// add to list and open
 		if (m_cf.logfiles.find(f) == m_cf.logfiles.end()) {
@@ -183,7 +202,7 @@ void KLogWidget::dropEvent(QDropEvent *ev)
 
 void KLogWidget::dragEnterEvent(QDragEnterEvent *ev)
 {
-    fprintf(stderr, "KLogWidget::dragEnterEvent()\n");
+//    fprintf(stderr, "KLogWidget::dragEnterEvent()\n");
 
     ev->accept(QUriDrag::canDecode(ev));
 }
@@ -266,7 +285,7 @@ QString KLogWidget::formatName(const QString &name)
 
 void KLogWidget::updateConf()
 {
-    fprintf(stderr, "KLogWidget::updateConf()\n");
+//    fprintf(stderr, "KLogWidget::updateConf()\n");
 
     // list of files
     if(m_files)
@@ -302,7 +321,7 @@ void KLogWidget::reopen()
 
 void KLogWidget::addFile(const QString &name)
 {
-    fprintf(stderr, "KLogWidget::addFile(%s)\n", (const char *)name);
+//    fprintf(stderr, "KLogWidget::addFile(%s)\n", (const char *)name);
 
     KLogFile *f = new KLogFile(name, this, m_cf);
     if(! f->m_file->isOpen())
